@@ -1,4 +1,4 @@
-use trillium::http_types::Method;
+use trillium::Method;
 use trillium_head::*;
 use trillium_testing::{prelude::*, TestConn};
 
